# crankshaft

[![GitHub Actions](https://github.com/reapermc/crankshaft/workflows/CI/badge.svg)](https://github.com/reapermc/crankshaft/actions)

> Flow control library for the Bolt scripting language.

## Installation

```bash
pip install crankshaft
```

---

License - [MIT](https://github.com/reapermc/crankshaft/blob/main/LICENSE)

